/*
 * file: pv_get.h
 * This file is part of the libpv library.
 *
 * Copyright 2005 Pengutronix
 *
 * Please send bug reports to bugs@pengutronix.de
 *
 * See COPYING for the status of this software.
 */

#ifndef PV_GET_H
#define PV_GET_H

#include <libpv_config.h>

#include <inttypes.h>

#include <pv_types.h>
#include <pv_register.h>

static inline uint8_t pv_get_uint8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->u8);
}

static inline int8_t pv_get_int8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->s8);
}


static inline uint16_t pv_get_uint16	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->u16);
}

static inline int16_t pv_get_int16	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->s16);
}


static inline uint32_t pv_get_uint32	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->u32);
}

static inline int32_t pv_get_int32	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->s32);
}


static inline uint64_t pv_get_uint64	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->u64);
}

static inline int64_t pv_get_int64	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->s64);
}

static inline float pv_get_float	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->f);
}


static inline double pv_get_double	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return *(pv_to_abs_addr(engine, pv)->d);
}

static inline const uint8_t* pv_get_uint8_array	(const struct pv_engine	*engine,
					 	 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->u8);
}

static inline const int8_t* pv_get_int8_array	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->s8);
}


static inline const uint16_t* pv_get_uint16_array (const struct pv_engine	*engine,
						   const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->u16);
}

static inline const int16_t* pv_get_int16_array (const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->s16);
}


static inline const uint32_t* pv_get_uint32_array(const struct pv_engine	*engine,
						  const struct pv		*pv)
{
	return (pv_to_abs_addr(engine, pv)->u32);
}

static inline const int32_t* pv_get_int32_array (const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->s32);
}


static inline const uint64_t* pv_get_uint64_array (const struct pv_engine	*engine,
						   const struct pv		*pv)
{
	return (pv_to_abs_addr(engine, pv)->u64);
}

static inline const int64_t* pv_get_int64_array (const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->s64);
}

static inline const float* pv_get_float_array (const struct pv_engine	*engine,
					       const struct pv		*pv)
{
	return (pv_to_abs_addr(engine, pv)->f);
}


static inline const double* pv_get_double_array (const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return (pv_to_abs_addr(engine, pv)->d);
}

#endif	/* !PV_GET_H */
